@@ -1,9 +1,9 @@
-package Dist::Zilla::Plugin::GitHub; # git description: v0.41-8-gb14f403
+package Dist::Zilla::Plugin::GitHub; # git description: v0.42-7-gef92c3f
 # ABSTRACT: Plugins to integrate Dist::Zilla with GitHub
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use JSON::MaybeXS;
 use Moose;
@@ -136,8 +136,9 @@ sub _get_repo_name {
 
     if ($repo !~ /.*\/.*/) {
         ($login, undef, undef) = $self->_get_credentials(1);
-
-        $repo = "$login/$repo";
+        if (defined $login) {
+            $repo = "$login/$repo";
+        }
     }
 
     return $repo;
@@ -186,7 +187,7 @@ Dist::Zilla::Plugin::GitHub - Plugins to integrate Dist::Zilla with GitHub
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -220,7 +221,7 @@ Alessandro Ghedini <alexbio@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alessandro Ghedini Karen Etheridge Mike Friedman Dave Rolsky Rafael Kitover Jeffrey Ryan Thalhammer Doherty Vyacheslav Matyukhin Alexandr Ciornii Brian Phillips Chris Weyl Ioan Rogers Jose Luis Perez Diez Ricardo Signes
+=for stopwords Alessandro Ghedini Karen Etheridge Mike Friedman Dave Rolsky Jeffrey Ryan Thalhammer Doherty Rafael Kitover Ricardo Signes Vyacheslav Matyukhin Alexandr Ciornii Brian Phillips Chris Weyl Ioan Rogers Jose Luis Perez Diez Mohammad S Anwar
 
 =over 4
 
@@ -242,10 +243,6 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Rafael Kitover <rkitover@cpan.org>
-
-=item *
-
 Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =item *
@@ -254,6 +251,14 @@ Mike Doherty <doherty@cs.dal.ca>
 
 =item *
 
+Rafael Kitover <rkitover@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
 Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
 
 =item *
@@ -278,7 +283,7 @@ Jose Luis Perez Diez <jluis@escomposlinux.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =back
 
