@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHub::Create;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use JSON::MaybeXS;
 use Moose;
@@ -205,98 +205,7 @@ sub _confirm {
     return $self->zilla->chrome->prompt_yn($prompt, {default => 1} );
 }
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =over
-#pod
-#pod =item C<repo>
-#pod
-#pod Specifies the name of the GitHub repository to be created (by default the name
-#pod of the dist is used). This can be a template, so something like the following
-#pod will work:
-#pod
-#pod     repo = {{ lc $dist->name }}
-#pod
-#pod =item C<org>
-#pod
-#pod Specifies the name of a GitHub organization in which to create the repository
-#pod (by default the repository is created in the user's account).
-#pod
-#pod =item C<prompt>
-#pod
-#pod Prompt for confirmation before creating a GitHub repository if this option is
-#pod set to true (default is false).
-#pod
-#pod =item C<public>
-#pod
-#pod Create a public repository if this option is set to true (default), otherwise
-#pod create a private repository.
-#pod
-#pod =item C<remote>
-#pod
-#pod Specifies the git remote name to be added (default 'origin'). This will point to
-#pod the newly created GitHub repository's private URL. See L</"ADDING REMOTE"> for
-#pod more info.
-#pod
-#pod =item C<has_issues>
-#pod
-#pod Enable issues for the new repository if this option is set to true (default).
-#pod
-#pod =item C<has_wiki>
-#pod
-#pod Enable the wiki for the new repository if this option is set to true (default).
-#pod
-#pod =item C<has_downloads>
-#pod
-#pod Enable downloads for the new repository if this option is set to true (default).
-#pod
-#pod =item C<prompt_2fa>
-#pod
-#pod Prompt for GitHub two-factor authentication code if this option is set to true
-#pod (default is false). If this option is set to false but GitHub requires 2fa for
-#pod the login, it'll be automatically enabled.
-#pod
-#pod =back
-#pod
-#pod =head1 ADDING REMOTE
-#pod
-#pod By default C<GitHub::Create> adds a new git remote pointing to the newly created
-#pod GitHub repository's private URL B<if, and only if,> a git repository has already
-#pod been initialized, and if the remote doesn't already exist in that repository.
-#pod
-#pod To take full advantage of this feature you should use, along with C<GitHub::Create>,
-#pod the L<Dist::Zilla::Plugin::Git::Init> plugin, leaving blank its C<remote> option,
-#pod as follows:
-#pod
-#pod     [Git::Init]
-#pod     ; here goes your Git::Init config, remember
-#pod     ; to not set the 'remote' option
-#pod     [GitHub::Create]
-#pod
-#pod You may set your preferred remote name, by setting the C<remote> option of the
-#pod C<GitHub::Create> plugin, as follows:
-#pod
-#pod     [Git::Init]
-#pod     [GitHub::Create]
-#pod     remote = myremote
-#pod
-#pod Remember to put C<[Git::Init]> B<before> C<[GitHub::Create]>.
-#pod
-#pod After the new remote is added, the current branch will track it, unless remote
-#pod tracking for the branch was already set. This may allow one to use the
-#pod L<Dist::Zilla::Plugin::Git::Push> plugin without the need to do a C<git push>
-#pod between the C<dzil new> and C<dzil release>. Note though that this will work
-#pod only when the C<push.default> Git configuration option is set to either
-#pod C<upstream> or C<simple> (which will be the default in Git 2.0). If you are
-#pod using an older Git or don't want to change your config, you may want to have a
-#pod look at L<Dist::Zilla::Plugin::Git::PushInitial>.
-#pod
-#pod =cut
-
-no Moose;
-
 __PACKAGE__->meta->make_immutable;
-
 1; # End of Dist::Zilla::Plugin::GitHub::Create
 
 __END__
@@ -311,7 +220,7 @@ Dist::Zilla::Plugin::GitHub::Create - Create a new GitHub repo on dzil new
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
