@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHub::Meta;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use JSON::MaybeXS;
 use Moose;
@@ -184,51 +184,6 @@ sub metadata {
     return $meta;
 }
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =over
-#pod
-#pod =item C<repo>
-#pod
-#pod The name of the GitHub repository. By default the name will be extracted from
-#pod the URL of the remote specified in the C<remote> option, and if that fails the
-#pod dist name (from dist.ini) is used. It can also be in the form C<user/repo>
-#pod when it belongs to another GitHub user/organization.
-#pod
-#pod =item C<remote>
-#pod
-#pod The name of the Git remote pointing to the GitHub repository (C<"origin"> by
-#pod default). This is used when trying to guess the repository name.
-#pod
-#pod =item C<homepage>
-#pod
-#pod The META homepage field will be set to the value of the homepage field set on
-#pod the GitHub repository's info if this option is set to true (default).
-#pod
-#pod =item C<wiki>
-#pod
-#pod The META homepage field will be set to the URL of the wiki of the GitHub
-#pod repository, if this option is set to true (default is false) and if the GitHub
-#pod Wiki happens to be activated (see the GitHub repository's C<Admin> panel).
-#pod
-#pod =item C<bugs>
-#pod
-#pod The META bugtracker web field will be set to the issue's page of the repository
-#pod on GitHub, if this options is set to true (default) and if the GitHub Issues happen to
-#pod be activated (see the GitHub repository's C<Admin> panel).
-#pod
-#pod =item C<fork>
-#pod
-#pod If the repository is a GitHub fork of another repository this option will make
-#pod all the information be taken from the original repository instead of the forked
-#pod one, if it's set to true (default).
-#pod
-#pod =back
-#pod
-#pod =cut
-
-no Moose;
-
 __PACKAGE__->meta->make_immutable;
 
 1; # End of Dist::Zilla::Plugin::GitHub::Meta
@@ -245,7 +200,7 @@ Dist::Zilla::Plugin::GitHub::Meta - Add a GitHub repo's info to META.{yml,json}
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
