@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::GitHub::Update;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use JSON::MaybeXS;
 use Moose;
@@ -92,6 +92,10 @@ sub after_release {
     return if (!$login);
 
     my $repo_name = $self->_get_repo_name($login);
+    if (not $repo_name) {
+        $self->log('cannot update GitHub repository info');
+        return;
+    }
 
     $self->log("Updating GitHub repository info");
 
@@ -169,68 +173,7 @@ sub _current_params {
     return $self->_check_response($response);
 }
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =over
-#pod
-#pod =item C<repo>
-#pod
-#pod The name of the GitHub repository. By default the name will be extracted from
-#pod the URL of the remote specified in the C<remote> option, and if that fails the
-#pod dist name (from dist.ini) is used. It can also be in the form C<user/repo>
-#pod when it belongs to another GitHub user/organization.
-#pod
-#pod =item C<remote>
-#pod
-#pod The name of the Git remote pointing to the GitHub repository (C<"origin"> by
-#pod default). This is used when trying to guess the repository name.
-#pod
-#pod =item C<cpan>
-#pod
-#pod The GitHub homepage field will be set to the CPAN page (search.cpan.org) of the
-#pod module if this option is set to true (default),
-#pod
-#pod =item C<p3rl>
-#pod
-#pod The GitHub homepage field will be set to the p3rl.org shortened URL
-#pod (e.g. C<http://p3rl.org/My::Module>) if this option is set to true (default is
-#pod false).
-#pod
-#pod This takes precedence over the C<cpan> option (if both are true, p3rl will be
-#pod used).
-#pod
-#pod =item C<metacpan>
-#pod
-#pod The GitHub homepage field will be set to the metacpan.org distribution URL
-#pod (e.g. C<http://metacpan.org/release/My-Module>) if this option is set to true
-#pod (default is false).
-#pod
-#pod This takes precedence over the C<cpan> and C<p3rl> options (if all three are
-#pod true, metacpan will be used).
-#pod
-#pod =item C<meta_home>
-#pod
-#pod The GitHub homepage field will be set to the value present in the dist meta
-#pod (e.g. the one set by other plugins) if this option is set to true (default is
-#pod false). If no value is present in the dist meta, this option is ignored.
-#pod
-#pod This takes precedence over the C<metacpan>, C<cpan> and C<p3rl> options (if all
-#pod four are true, meta_home will be used).
-#pod
-#pod =item C<prompt_2fa>
-#pod
-#pod Prompt for GitHub two-factor authentication code if this option is set to true
-#pod (default is false). If this option is set to false but GitHub requires 2fa for
-#pod the login, it'll be automatically enabled.
-#pod
-#pod =back
-#pod
-#pod =cut
-
-no Moose;
-
 __PACKAGE__->meta->make_immutable;
-
 1; # End of Dist::Zilla::Plugin::GitHub::Update
 
 __END__
@@ -245,7 +188,7 @@ Dist::Zilla::Plugin::GitHub::Update - Update a GitHub repo's info on release
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
