@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::GitHub;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Moose;
 
@@ -154,94 +154,7 @@ sub configure {
     );
 }
 
-#pod =head1 ATTRIBUTES
-#pod
-#pod =over
-#pod
-#pod =item C<repo>
-#pod
-#pod The name of the GitHub repository. By default the name will be extracted from
-#pod the URL of the remote specified in the C<remote> option, and if that fails the
-#pod dist name (from dist.ini) is used. It can also be in the form C<user/repo>
-#pod when it belongs to another GitHub user/organization.
-#pod
-#pod =item C<remote>
-#pod
-#pod The name of the Git remote pointing to the GitHub repository (C<"origin"> by
-#pod default). This is used when trying to guess the repository name.
-#pod
-#pod =item C<homepage>
-#pod
-#pod The META homepage field will be set to the value of the homepage field set on
-#pod the GitHub repository's info if this option is set to true (default).
-#pod
-#pod =item C<wiki>
-#pod
-#pod The META homepage field will be set to the URL of the wiki of the GitHub
-#pod repository, if this option is set to true (default is false) and if the GitHub
-#pod Wiki happens to be activated (see the GitHub repository's C<Admin> panel).
-#pod
-#pod =item C<bugs>
-#pod
-#pod The META bugtracker web field will be set to the issue's page of the repository
-#pod on GitHub, if this options is set to true (default) and if the GitHub Issues happen to
-#pod be activated (see the GitHub repository's C<Admin> panel).
-#pod
-#pod =item C<fork>
-#pod
-#pod If the repository is a GitHub fork of another repository this option will make
-#pod all the information be taken from the original repository instead of the forked
-#pod one, if it's set to true (default).
-#pod
-#pod =item C<cpan>
-#pod
-#pod The GitHub homepage field will be set to the CPAN page (search.cpan.org) of the
-#pod module if this option is set to true (default),
-#pod
-#pod =item C<p3rl>
-#pod
-#pod The GitHub homepage field will be set to the p3rl.org shortened URL
-#pod (e.g. C<http://p3rl.org/My::Module>) if this option is set to true (default is
-#pod false).
-#pod
-#pod This takes precedence over the C<cpan> option (if both are true, p3rl will be
-#pod used).
-#pod
-#pod =item C<metacpan>
-#pod
-#pod The GitHub homepage field will be set to the metacpan.org distribution URL
-#pod (e.g. C<http://metacpan.org/release/My-Module>) if this option is set to true
-#pod (default is false).
-#pod
-#pod This takes precedence over the C<cpan> and C<p3rl> options (if all three are
-#pod true, metacpan will be used).
-#pod
-#pod =item C<meta_home>
-#pod
-#pod The GitHub homepage field will be set to the value present in the dist meta
-#pod (e.g. the one set by other plugins) if this option is set to true (default is
-#pod false). If no value is present in the dist meta, this option is ignored.
-#pod
-#pod This takes precedence over the C<metacpan>, C<cpan> and C<p3rl> options (if all
-#pod four are true, meta_home will be used).
-#pod
-#pod =item C<prompt_2fa>
-#pod
-#pod Prompt for GitHub two-factor authentication code if this option is set to true
-#pod (default is false).
-#pod
-#pod =back
-#pod
-#pod =head1 SEE ALSO
-#pod
-#pod L<Dist::Zilla::Plugin::GitHub::Meta>, L<Dist::Zilla::Plugin::GitHub::Update>
-#pod
-#pod =cut
-
-no Moose;
-
 __PACKAGE__->meta->make_immutable;
-
 1; # End of Dist::Zilla::PluginBundle::GitHub
 
 __END__
@@ -256,7 +169,7 @@ Dist::Zilla::PluginBundle::GitHub - GitHub plugins all-in-one
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
